==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/OperatorHubSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OperatorHubSpecFluentImpl<A extends io.fabric8.openshift.api.model.OperatorHubSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OperatorHubSpecFluent<A>{
  public OperatorHubSpecFluentImpl() {
  }
  public OperatorHubSpecFluentImpl(io.fabric8.openshift.api.model.OperatorHubSpec instance) {
    this.withDisableAllDefaultSources(instance.getDisableAllDefaultSources()); 
    this.withSources(instance.getSources()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean disableAllDefaultSources;
  private java.util.List<io.fabric8.openshift.api.model.HubSourceBuilder> sources =  new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getDisableAllDefaultSources() {
    return this.disableAllDefaultSources;
  }
  public A withDisableAllDefaultSources(java.lang.Boolean disableAllDefaultSources) {
    this.disableAllDefaultSources=disableAllDefaultSources; return (A) this;
  }
  public java.lang.Boolean hasDisableAllDefaultSources() {
    return this.disableAllDefaultSources != null;
  }
  public A addToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").add(index >= 0 ? index : _visitables.get("sources").size(), builder);this.sources.add(index >= 0 ? index : sources.size(), builder); return (A)this;
  }
  public A setToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);
    if (index < 0 || index >= _visitables.get("sources").size()) { _visitables.get("sources").add(builder); } else { _visitables.get("sources").set(index, builder);}
    if (index < 0 || index >= sources.size()) { sources.add(builder); } else { sources.set(index, builder);}
     return (A)this;
  }
  public A addToSources(io.fabric8.openshift.api.model.HubSource... items) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").add(builder);this.sources.add(builder);} return (A)this;
  }
  public A addAllToSources(java.util.Collection<io.fabric8.openshift.api.model.HubSource> items) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").add(builder);this.sources.add(builder);} return (A)this;
  }
  public A removeFromSources(io.fabric8.openshift.api.model.HubSource... items) {
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
  }
  public A removeAllFromSources(java.util.Collection<io.fabric8.openshift.api.model.HubSource> items) {
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromSources(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    if (sources == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.HubSourceBuilder> each = sources.iterator();
    final List visitables = _visitables.get("sources");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.HubSourceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildSources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.HubSource> getSources() {
    return build(sources);
  }
  public java.util.List<io.fabric8.openshift.api.model.HubSource> buildSources() {
    return build(sources);
  }
  public io.fabric8.openshift.api.model.HubSource buildSource(java.lang.Integer index) {
    return this.sources.get(index).build();
  }
  public io.fabric8.openshift.api.model.HubSource buildFirstSource() {
    return this.sources.get(0).build();
  }
  public io.fabric8.openshift.api.model.HubSource buildLastSource() {
    return this.sources.get(sources.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.HubSource buildMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.HubSourceBuilder item: sources) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.HubSourceBuilder item: sources) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSources(java.util.List<io.fabric8.openshift.api.model.HubSource> sources) {
    if (this.sources != null) { _visitables.get("sources").removeAll(this.sources);}
    if (sources != null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>(); for (io.fabric8.openshift.api.model.HubSource item : sources){this.addToSources(item);}} else { this.sources = null;} return (A) this;
  }
  public A withSources(io.fabric8.openshift.api.model.HubSource... sources) {
    if (this.sources != null) {this.sources.clear();}
    if (sources != null) {for (io.fabric8.openshift.api.model.HubSource item :sources){ this.addToSources(item);}} return (A) this;
  }
  public java.lang.Boolean hasSources() {
    return sources != null && !sources.isEmpty();
  }
  public A addNewSource(java.lang.Boolean disabled,java.lang.String name) {
    return (A)addToSources(new HubSource(disabled, name));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> addNewSource() {
    return new io.fabric8.openshift.api.model.OperatorHubSpecFluentImpl.SourcesNestedImpl();
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> addNewSourceLike(io.fabric8.openshift.api.model.HubSource item) {
    return new io.fabric8.openshift.api.model.OperatorHubSpecFluentImpl.SourcesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> setNewSourceLike(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
    return new io.fabric8.openshift.api.model.OperatorHubSpecFluentImpl.SourcesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editSource(java.lang.Integer index) {
    if (sources.size() <= index) throw new RuntimeException("Can't edit sources. Index exceeds size.");
    return setNewSourceLike(index, buildSource(index));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editFirstSource() {
    if (sources.size() == 0) throw new RuntimeException("Can't edit first sources. The list is empty.");
    return setNewSourceLike(0, buildSource(0));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editLastSource() {
    int index = sources.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last sources. The list is empty.");
    return setNewSourceLike(index, buildSource(index));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<sources.size();i++) { 
    if (predicate.test(sources.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching sources. No match found.");
    return setNewSourceLike(index, buildSource(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperatorHubSpecFluentImpl that = (OperatorHubSpecFluentImpl) o;
    if (disableAllDefaultSources != null ? !disableAllDefaultSources.equals(that.disableAllDefaultSources) :that.disableAllDefaultSources != null) return false;
    if (sources != null ? !sources.equals(that.sources) :that.sources != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disableAllDefaultSources,  sources,  additionalProperties,  super.hashCode());
  }
  public class SourcesNestedImpl<N> extends io.fabric8.openshift.api.model.HubSourceFluentImpl<io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<N>> implements io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SourcesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.HubSourceBuilder(this, item);
    }
    SourcesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.HubSourceBuilder(this);
    }
    io.fabric8.openshift.api.model.HubSourceBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) OperatorHubSpecFluentImpl.this.setToSources(index,builder.build());
    }
    public N endSource() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/OperatorHubSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OperatorHubSpecFluentImpl<A extends io.fabric8.openshift.api.model.OperatorHubSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OperatorHubSpecFluent<A>{
  public OperatorHubSpecFluentImpl() {
  }
  public OperatorHubSpecFluentImpl(io.fabric8.openshift.api.model.OperatorHubSpec instance) {
    this.withDisableAllDefaultSources(instance.getDisableAllDefaultSources()); 
    this.withSources(instance.getSources()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean disableAllDefaultSources;
  private java.util.List<io.fabric8.openshift.api.model.HubSourceBuilder> sources =  new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getDisableAllDefaultSources() {
    return this.disableAllDefaultSources;
  }
  public A withDisableAllDefaultSources(java.lang.Boolean disableAllDefaultSources) {
    this.disableAllDefaultSources=disableAllDefaultSources; return (A) this;
  }
  public java.lang.Boolean hasDisableAllDefaultSources() {
    return this.disableAllDefaultSources != null;
  }
  public A addToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").add(index >= 0 ? index : _visitables.get("sources").size(), builder);this.sources.add(index >= 0 ? index : sources.size(), builder); return (A)this;
  }
  public A setToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);
    if (index < 0 || index >= _visitables.get("sources").size()) { _visitables.get("sources").add(builder); } else { _visitables.get("sources").set(index, builder);}
    if (index < 0 || index >= sources.size()) { sources.add(builder); } else { sources.set(index, builder);}
     return (A)this;
  }
  public A addToSources(io.fabric8.openshift.api.model.HubSource... items) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").add(builder);this.sources.add(builder);} return (A)this;
  }
  public A addAllToSources(java.util.Collection<io.fabric8.openshift.api.model.HubSource> items) {
    if (this.sources == null) {this.sources = new java.util.ArrayList<io.fabric8.openshift.api.model.HubSourceBuilder>();}
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").add(builder);this.sources.add(builder);} return (A)this;
  }
  public A removeFromSources(io.fabric8.openshift.api.model.HubSource... items) {
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
  }
  public A removeAllFromSources(java.util.Collection<io.fabric8.openshift.api.model.HubSource> items) {
    for (io.fabric8.openshift.api.model.HubSource item : items) {io.fabric8.openshift.api.model.HubSourceBuilder builder = new io.fabric8.openshift.api.model.HubSourceBuilder(item);_visitables.get("sources").remove(builder);if (this.sources != null) {this.sources.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromSources(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    if (sources == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.HubSourceBuilder> each = sources.iterator();
    final List visitables = _visitables.get("sources");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.HubSourceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildSources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.HubSource> getSources() {
    return build(sources);
  }
  public java.util.List<io.fabric8.openshift.api.model.HubSource> buildSources() {
    return build(sources);
  }
  public io.fabric8.openshift.api.model.HubSource buildSource(java.lang.Integer index) {
    return this.sources.get(index).build();
  }
  public io.fabric8.openshift.api.model.HubSource buildFirstSource() {
    return this.sources.get(0).build();
  }
  public io.fabric8.openshift.api.model.HubSource buildLastSource() {
    return this.sources.get(sources.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.HubSource buildMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.HubSourceBuilder item: sources) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.HubSourceBuilder item: sources) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSources(java.util.List<io.fabric8.openshift.api.model.HubSource> sources) {
    if (this.sources != null) { _visitables.get("sources").removeAll(this.sources);}
    if (sources != null) {this.sources = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.HubSource item : sources){this.addToSources(item);}} else { this.sources = null;} return (A) this;
  }
  public A withSources(io.fabric8.openshift.api.model.HubSource... sources) {
    if (this.sources != null) {this.sources.clear();}
    if (sources != null) {for (io.fabric8.openshift.api.model.HubSource item :sources){ this.addToSources(item);}} return (A) this;
  }
  public java.lang.Boolean hasSources() {
    return sources != null && !sources.isEmpty();
  }
  public A addNewSource(java.lang.Boolean disabled,java.lang.String name) {
    return (A)addToSources(new HubSource(disabled, name));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> addNewSource() {
    return new io.fabric8.openshift.api.model.OperatorHubSpecFluentImpl.SourcesNestedImpl();
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> addNewSourceLike(io.fabric8.openshift.api.model.HubSource item) {
    return new io.fabric8.openshift.api.model.OperatorHubSpecFluentImpl.SourcesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> setNewSourceLike(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
    return new io.fabric8.openshift.api.model.OperatorHubSpecFluentImpl.SourcesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editSource(java.lang.Integer index) {
    if (sources.size() <= index) throw new RuntimeException("Can't edit sources. Index exceeds size.");
    return setNewSourceLike(index, buildSource(index));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editFirstSource() {
    if (sources.size() == 0) throw new RuntimeException("Can't edit first sources. The list is empty.");
    return setNewSourceLike(0, buildSource(0));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editLastSource() {
    int index = sources.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last sources. The list is empty.");
    return setNewSourceLike(index, buildSource(index));
  }
  public io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<A> editMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<sources.size();i++) { 
    if (predicate.test(sources.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching sources. No match found.");
    return setNewSourceLike(index, buildSource(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperatorHubSpecFluentImpl that = (OperatorHubSpecFluentImpl) o;
    if (disableAllDefaultSources != null ? !disableAllDefaultSources.equals(that.disableAllDefaultSources) :that.disableAllDefaultSources != null) return false;
    if (sources != null ? !sources.equals(that.sources) :that.sources != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disableAllDefaultSources,  sources,  additionalProperties,  super.hashCode());
  }
  public class SourcesNestedImpl<N> extends io.fabric8.openshift.api.model.HubSourceFluentImpl<io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<N>> implements io.fabric8.openshift.api.model.OperatorHubSpecFluent.SourcesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SourcesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.HubSource item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.HubSourceBuilder(this, item);
    }
    SourcesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.HubSourceBuilder(this);
    }
    io.fabric8.openshift.api.model.HubSourceBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) OperatorHubSpecFluentImpl.this.setToSources(index,builder.build());
    }
    public N endSource() {
      return and();
    }
    
  }
  
}
